@@ -63,7 +63,7 @@ bool Sweeper::RequiresKnobs() const
 }
 
 
-void Sweeper::EvaluateThemeName()
+void Sweeper::SetThemeName(const std::wstring& themeName)
 {
   for (size_t i=0; i<themes.size(); i++) {
     if (themes[i].name==themeName) {
