@@ -115,7 +115,7 @@ public:
 
   bool RequiresKnobs() const;
 
-  void EvaluateThemeName();
+  void SetThemeName(const std::wstring& themeName);
 
   void CalcSize();
 
