@@ -699,7 +699,7 @@ public:
 
     hPanel=Lum::HPanel::Create(true,false);
 
-    hPanel->Add(Lum::Toggle::Create(L"Zoom",zoom));
+    hPanel->Add(Lum::Toggle::Create(L"Zoom out",zoom));
     hPanel->Add(Lum::Button::Create(L"_New",newGameAction));
     hPanel->Add(new Lum::HSpace(Lum::Space::sizeNormal,true));
 
